@@ -97,7 +97,9 @@ class IDE(PDE):
     def test(self):
         if self.num_test is None:
             self.test_x = self.train_x[sum(self.num_bcs) :]
-            self.test_y = self.train_y[sum(self.num_bcs) :] if self.train_y else None
+            self.test_y = (
+                self.train_y[sum(self.num_bcs) :] if self.train_y is not None else None
+            )
         else:
             self.test_x = self.test_points()
             x_quad = self.quad_points(self.test_x)
